/***************************************************************************
 $RCSfile: flagstaff.h,v $
                             -------------------
    cvs         : $Id: flagstaff.h,v 1.11 2005/09/07 15:38:38 aquamaniac Exp $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef AQHBCI_KDE_FLAGSTAFF_H
#define AQHBCI_KDE_FLAGSTAFF_H

class FlagStaff;

#include <qobject.h>

#include <qbanking/qbflagstaff.h>

#include "refpointer.h"
#include "transaction.h"


class FlagStaff: public QBFlagStaff {
  Q_OBJECT
public:
  FlagStaff();
  virtual ~FlagStaff();

  void payeesUpdated();
  void transfersUpdated();
  void datedTransfersUpdated();
  void standingOrdersUpdated();
  void categoriesUpdated();
  void rebuildExportMenu();

signals:
  void signalTransfersUpdated();
  void signalDatedTransfersUpdated();
  void signalStandingOrdersUpdated();
  void signalRebuildExportMenu();
  void signalPayeesUpdated();
  void signalCategoriesUpdated();

};




#endif /* AQHBCI_KDE_FLAGSTAFF_H */

